# Utils

General utilities complimenting and expanding on standard python.

## Setup & Install

https://pypi.org/project/utils-nuuuwan/#history

```
pip install utils-nuuuwan
```

## Version History

### 1.0.35 (NOT RELEASED AS YET)

* Added xmlx, which contains various utils for manipulating xml

### 1.0.34
(No Release)

### 1.0.33

* Added logx. get_logger creates a custom logger that prints log messages in color
